# frozen_string_literal: true

=begin ========================================================================
= Copyright (c) AgiliCity d.o.o. 2024. All Rights Reserved.                   =
=                                                                             =
= By using this software, you agree to respect Terms and Conditions, End User =
= License Agreement and other related documents that can be found on our      =
= website (https://modelur.com/legal/).                                       =
=                                                                             =
= Make sure this file is not encoded by Ruby Encoder:                         =
= RubyEncoder:DO_NOT_ENCODE                                                   =
=end ==========================================================================

require 'sketchup'
require 'extensions'

module Modelur
  MODELUR_VERSION_EXTERNAL = '2024.11.11'
  bootstrap = 'bootstrap'

  MODELUR_EXPIRATION = 1739660400
  if Time.now.to_i > MODELUR_EXPIRATION
    bootstrap = 'bootstrap_fallback'
    LOAD_ERROR = 'modelur_expired'
  end

  expiration_string = Time.at(MODELUR_EXPIRATION - 86400).strftime('%A, %b %d %Y')

  MIN_SU_VERSION = 19
  MAX_SU_VERSION = 24

  SU_VERSION_NUMBER = Sketchup.version_number
  su_version = SU_VERSION_NUMBER / 100000000
  if su_version < MIN_SU_VERSION or su_version > MAX_SU_VERSION
    bootstrap = 'bootstrap_fallback'
    LOAD_ERROR = 'incompatible_su_version'
  end

  EXTENSION_NAME = 'Modelur'
  SU_EXTENSION = SketchupExtension.new(EXTENSION_NAME, File.join('Modelur', bootstrap))
  SU_EXTENSION.creator = 'AgiliCity'
  SU_EXTENSION.copyright = '© AgiliCity d.o.o. 2024. All Rights Reserved.'
  SU_EXTENSION.version = "#{MODELUR_VERSION_EXTERNAL}, valid until #{expiration_string}."
  SU_EXTENSION.description = 'Modelur is SketchUp Extension for parametric urban design. For more information,
 please visit https://modelur.com.'
  Sketchup.register_extension(SU_EXTENSION, true)
end
