# frozen_string_literal: true

=begin ========================================================================
= Copyright (c) AgiliCity d.o.o. 2024. All Rights Reserved.                   =
=                                                                             =
= By using this software, you agree to respect Terms and Conditions, End User =
= License Agreement and other related documents that can be found on our      =
= website (https://modelur.com/legal/).                                       =
=                                                                             =
= Make sure this file is not encoded by Ruby Encoder:                         =
= RubyEncoder:DO_NOT_ENCODE                                                   =
=end ==========================================================================
require 'rbconfig'
require 'pathname'
require_relative 'src/ui/sketchup_ui'

module Modelur
  module_function

  dir = __dir__.dup
  dir.force_encoding('UTF-8') if dir.respond_to?(:force_encoding)
  MODELUR_SRC_PATH = Pathname.new(File.expand_path(dir)).cleanpath.to_s
  IMG_PATH = Pathname.new(File.join(MODELUR_SRC_PATH, 'img')).cleanpath.to_s
  ICON_EXT = case RbConfig::CONFIG['host_os']
             when /darwin|mac os/
               '.pdf'
             else
               '.svg'
             end

  def initialize_menu_and_toolbar
    @sketchup_ui = Ui::SketchupUi.new(nil)
    add_modelur_command
  end

  def add_modelur_command
    menu_text = 'Initialize Modelur'
    cmd = UI::Command.new(menu_text) do
      if LOAD_ERROR == 'modelur_expired'
        modelur_expired
      else
        incompatible_su_version
      end
    end
    icon = File.join(IMG_PATH, "su_initialize_modelur#{ICON_EXT}")
    cmd.large_icon = icon
    cmd.small_icon = icon
    cmd.tooltip = menu_text
    @sketchup_ui.modelur_menu.add_item(cmd)
    @sketchup_ui.modelur_toolbar.add_item(cmd)
  end

  def modelur_expired
    date = Time.at(MODELUR_EXPIRATION).strftime('%b-%d-%Y')
    msg = 'Your installed version of Modelur (%<version>s) expired on %<date>s. '
    msg += "In order to keep on using it, you will need to upgrade Modelur to a newer version.\n\n"
    msg += 'Would you like to download the latest Modelur RBZ installer package?'
    status = UI.messagebox(format(msg, version: MODELUR_VERSION_EXTERNAL, date: date), MB_YESNO)
    return unless status == IDYES

    UI.openURL('https://modelur.com/download-latest-rbz-installer')
    msg =  'After you have downloaded Modelur RBZ installer, please install it'
    msg += " using SketchUp Extension Manager. We will open it for you when you click OK button below.\n\n"
    msg += 'Once you complete the installation, please restart SketchUp.'
    UI.messagebox(msg)
    UI.show_extension_manager
  end

  def incompatible_su_version
    msg =  "Modelur %<mdlr_version>s can not run on your version of SketchUp (20%<su_version>s).\n\n"
    msg += "Supported versions for this release of Modelur are from SketchUp 20%<su_min>s to SketchUp 20%<su_max>s.\n\n"
    msg += 'Please make sure you use supported version of SketchUp.'
    UI.messagebox(format(msg, su_min: MIN_SU_VERSION, su_max: MAX_SU_VERSION,
                              su_version: Sketchup.version, mdlr_version: MODELUR_VERSION_EXTERNAL))
  end

  initialize_menu_and_toolbar
end
