# GSheets Sync

## Description

This is a minimal prototype of a plugin that sends Modelur data to a Google Sheet. Consider it a work in progress.

## Based on `excel_sync`

The architecture of this plugin is heavily inspired on its `excel_sync` counterpart.
Significant chunks of code have been taken from `excel_sync`.
Firstly because the intention was not to reinvent the wheel,
and secondly because in the future, I believe that certain functionality can actually be shared between these two plugins.
Namely: data providers. Modules in `gsheets_sync/data_providers` folder are all candidates for this.

## Files and Folders

### `command.rb`

Plugin entrypoint. Constructs main plugin class, and registers plugin to Modelur app UI controller.

### `plugin.rb`

Main plugin class. Constructs and references wrappers for web app and SketchUp model observer.

### `observer.rb`

Extends `SketchUp::ModelObserver`. Attaches a handlers to SketchUp callbacks.

### `web_app.rb`

Wraps `SketchUp::HtmlDialog`. Exposes select functionality for passing data to web app.

### `user_settings.rb`

Manages plugin user settings.

### `data_providers` Folder

Contain data providers for __buildings__, __land_uses__, and __city_blocks__ data sets.
I tried to make as little changes as possible to the same code used in `excel_sync`, and applied it to `gsheets_sync`.

### `constants.rb`

Constants.

## Integration Requirements

### `m4s-rewrite`

Small changes needed to be made to Modelur codebase outside of `gsheets_sync`.

- `Modelur trg_constants`- Added string constant that represents trigger for `GSheetsSync::Command`.
- `Modelur::Commands::TriggerActionCommand` - Added mapping of `GSheetsSync::Command` to the above mentioned string constant.

### `_react-ui` Submodule

- Type `ModelurActionTrigger` needs a string literal that needs to be equal to the string constant in `trg_constants`.
- Component `SimpleDataMenu` needs an action item for `gsheets_sync`.
  Prop `name` should be set to the string constant from `trg_constants`.
  Prop `label` requires i18n integration of relevant strings.
- Component `ExpertDataMenu` needs an action item for `gsheets_sync`.
  Again, prop `name` should be set to the string constant from `trg_constants`.
  Prop `label` requires i18n integration of relevant strings.

### `Modelur/i18n` Submodule

- Add translations for the label of action item React component.

## Development Setup

If developing `gsheets_sync` web app and this plugin in parallel, take care to run the web app on a smaller port number than the main Modelur React UI.
Otherwise, OAuth redirection may throw invalid redirect URL errors.

To set `gsheets_sync` web app URL, go to `gsheets_sync/constants.rb`.
To set `_react-ui`, go to `Modelur/src/ui/react_view.rb` and change `REACT_UI_HTML`.
To start Modelur React UI dev server, simply go to `_react-ui` and run `npm start`.

These instructions may become obsolete, but hopefully should remain helpful for some time.
