# frozen_string_literal: true

require_relative '../utils/formatting_utils'

=begin ========================================================================
= Copyright (c) AgiliCity d.o.o. 2024. All Rights Reserved.                   =
=                                                                             =
= By using this software, you agree to respect Terms and Conditions, End User =
= License Agreement and other related documents that can be found on our      =
= website (https://modelur.com/legal/).                                       =
=                                                                             =
= Make sure this file is not encoded by Ruby Encoder:                         =
= RubyEncoder:DO_NOT_ENCODE                                                   =
=end ==========================================================================
module Modelur
  module Ui
    class SketchupUi
      MENU_TITLE = 'Modelur'
      BEFORE_NEVER_SHOWN = -1

      attr_reader :modelur_menu

      attr_reader :modelur_toolbar

      def initialize(modelur_app)
        @modelur_app = modelur_app
        @modelur_menu = UI.menu.add_submenu(MENU_TITLE)
        @modelur_toolbar = UI::Toolbar.new(MENU_TITLE)
        @modelur_toolbar.show if @modelur_toolbar.get_last_state == BEFORE_NEVER_SHOWN
      end

      def show_warning(i18n_message, i18n_title: nil)
        show_message(i18n_message, MB_OK, icon: '⚠')
      end

      def show_error(i18n_message, i18n_title: nil)
        show_message(i18n_message, MB_OK, icon: '⛔')
      end

      def show_notification(i18n_message, i18n_title: nil)
        show_message(i18n_message, MB_OK, icon: '🔔')
      end

      def show_question(i18n_message, i18n_title: nil, callback_action: nil)
        result = show_message(i18n_message, MB_YESNO)
        return unless result == IDYES

        ui_utils = SketchupModel::Utils::UiUtils
        ui_utils.start_timer_with_error_handler(@modelur_app.error_handler, 0, repeat: false) do
          trigger_action_cmd.run(data: callback_action) if callback_action
        end
      end

      def show_question_with_response(i18n_message, callback_command:, i18n_title: nil)
        result = show_message(i18n_message, MB_YESNO)
        return unless result == IDYES

        callback_command.run
      end

      def show_confirmation(i18n_message, callback_action:, i18n_title: nil)
        show_notification(i18n_message, i18n_title: i18n_title)

        ui_utils = SketchupModel::Utils::UiUtils
        ui_utils.start_timer_with_error_handler(@modelur_app.error_handler, 0, repeat: false) do
          trigger_action_cmd.run(data: callback_action) if callback_action
        end
      end

      def show_message(i18n_message, button_options, icon: nil)
        i18n = Context.use_context(CTX_TRANSLATIONS)
        text = i18n.string(i18n_message)
        text = Utils::FormattingUtils.html_to_string(text)
        text = "#{icon}\n\n#{text}" if icon
        UI.messagebox(text, button_options)
      end

      def trigger_action_cmd
        return @trigger_action_cmd if @trigger_action_cmd

        RgLoader320.reload!
        require_relative '../commands/trigger_action_command'
        @trigger_action_cmd = Commands::TriggerActionCommand.new(@modelur_app)
      end
    end
  end
end
