# frozen_string_literal: true

=begin ========================================================================
= Copyright (c) AgiliCity d.o.o. 2024. All Rights Reserved.                   =
=                                                                             =
= By using this software, you agree to respect Terms and Conditions, End User =
= License Agreement and other related documents that can be found on our      =
= website (https://modelur.com/legal/).                                       =
=                                                                             =
= Make sure this file is not encoded by Ruby Encoder:                         =
= RubyEncoder:DO_NOT_ENCODE                                                   =
=end ==========================================================================
module Modelur
  module Utils
    module FormattingUtils
      def self.format_float(value, significant_figures = 3)
        return value.to_s if value.nil? or value.infinite? or value == 0

        return FormattingUtils.round_to_first_decimal(value, significant_figures - 1).to_s if value.abs < 1

        value = relative_round(value, significant_figures)
        return value.to_s if value.abs < 1000

        whole, decimal = value.to_s.split('.')
        whole = whole.reverse.gsub(/(\d{3})(?=\d)/, '\\1,').reverse
        [whole, decimal].compact.join('.')
      end

      def self.round_to_first_decimal(value, fixed_decimals = 2)
        first_nonzero = -Math.log10(value.abs).floor
        rounding = [fixed_decimals, first_nonzero].max
        value.round(rounding)
      end

      def self.relative_round(value, significant_figures = 3)
        return 0 if value == 0

        log = Math.log10(value.abs).floor
        rounding = significant_figures - log - 1
        rounding = 0 if rounding < 0
        value.round(rounding)
      end

      def self.titelize(string_value)
        string_value.split.map { |x| x[0].upcase + x[1..-1] }.join(' ')
      end

      def self.html_to_string(text)
        text.gsub('<br>', "\n")
      end
    end
  end
end
